add_rank: calculate ranks of a score column and adds result to a dataframe
Description
add_rank returns a copy of the passed data frame containing a new
column called rank which has the ranks of the named score column
Usage
add_rank(df, quo_score_col)
Arguments
- df
data frame
- quo_score_col
quoted score column name