Skip to contents

Determines statistical significance by checking if the bootstrap confidence interval for each treatment group overlaps with the control group's mean rank.

Usage

compute_significance(hrest)

Arguments

hrest

An hrest object from estimate

Value

A data frame with columns: group, significant (logical), p_value, stars

Examples

d <- make_data()
hr <- estimate(d, score, group, nits = 500)
compute_significance(hr)
#>   group significant p_value stars
#> 1     A          NA      NA      
#> 2     B        TRUE   0.004    **