factorise_cols: Convert named columns to factors

View source: R/functions.R

factorise_colsR Documentation

Convert named columns to factors

Description

factorise_cols returns a copy of the passed data frame in which all explicitly named columns are converted to factors with as.factor All columns with only NA values are ommitted.

Usage

factorise_cols(df, col_list)

Arguments

df

data frame

col_list

vector of quoted column names


besthr documentation built on March 18, 2026, 5:08 p.m.