Learn R Programming

besthr (version 0.3.2)

group_means: Get mean rank of groups in a data frame

Description

group_means groups the provided dataframe by a column and returns a summary dataframe with a mean column containing the mean of the group's rank column

Usage

group_means(df, quo_group_col)

Arguments

df

input data frame

quo_group_col

quoted group name containing the column to group on