Create ranked dots layer
layer_ranked_dots.RdCreates a ggplot2 layer showing ranked observations as points, where point size indicates the count of observations at each rank/group combination.
Examples
# \donttest{
d <- make_data()
hr <- estimate(d, score, group)
dv <- besthr_data_view(hr)
cfg <- besthr_plot_config()
# layer_ranked_dots returns layers to add to a ggplot
# }