Create technical replicate dots layer
layer_tech_rep_dots.RdCreates a ggplot2 layer showing raw score observations with technical replicates displayed separately. Points are sized by observation count.
layer_tech_rep_dots.RdCreates a ggplot2 layer showing raw score observations with technical replicates displayed separately. Points are sized by observation count.