make_data3: return a sample data set of random values for three groups...

View source: R/functions.R

make_data3R Documentation

return a sample data set of random values for three groups with three technical reps per group

Description

@examples

Usage

make_data3()

Details

d3 <- make_data3()

Value

tibble of random values for three groups with three technical reps per group


besthr documentation built on March 18, 2026, 5:08 p.m.