Skip to contents

Creates a raincloud plot specifically for bootstrap distributions, showing the distribution of bootstrap mean ranks with jittered points and summary statistics.

Usage

plot_bootstrap_raincloud(
  hrest,
  theme = "modern",
  colors = "okabe_ito",
  config = NULL
)

Arguments

hrest

An hrest object from estimate

theme

the visual theme to use. Either "modern" (default) or "classic"

colors

the color palette to use. Either "okabe_ito" (default), "default", or "viridis"

config

an optional besthr_plot_config object

Value

A ggplot object

Examples

# \donttest{
d <- make_data()
hr <- estimate(d, score, group, nits = 100)
plot_bootstrap_raincloud(hr)

# }