tech_rep_dot_plot: dot plot of score data with technical replicates

View source: R/plot-hrest.R

tech_rep_dot_plotR Documentation

dot plot of score data with technical replicates

Description

tech_rep_dot_plot returns a ggplot object of score data with group on technical replicate on the x-axis, score on the y-axis with point size representing the number of observations at that point. Facets represent individual groups

Usage

tech_rep_dot_plot(
  hrest,
  score_col,
  group_col,
  tech_rep_col,
  theme_style = "modern",
  color_palette = "okabe_ito"
)

Arguments

hrest

the hrest object from estimate

score_col

quoted score column name

group_col

quoted group column name

tech_rep_col

quoted tech replicate column name

theme_style

character specifying the theme style

color_palette

character specifying the color palette


besthr documentation built on March 18, 2026, 5:08 p.m.