Update a besthr plot configuration
update_config.RdCreates a new configuration by updating specific fields of an existing one.
Examples
cfg <- besthr_plot_config()
cfg2 <- update_config(cfg, theme_style = "modern", panel_widths = c(2, 1))
update_config.RdCreates a new configuration by updating specific fields of an existing one.
cfg <- besthr_plot_config()
cfg2 <- update_config(cfg, theme_style = "modern", panel_widths = c(2, 1))