| besthr_data_view | R Documentation |
Extracts and organizes data from an hrest object for plotting. Computes unified axis limits that ensure alignment between observation and bootstrap panels.
besthr_data_view(hrest, config = NULL)
hrest |
An hrest object from |
config |
A besthr_plot_config object (optional). If NULL, uses defaults. |
An object of class "besthr_data_view" containing ranked data, original data, bootstrap samples, group means, confidence intervals, group sample sizes, unified rank limits, group column symbol, column info, control group name, and quantile values.
d <- make_data()
hr <- estimate(d, score, group)
dv <- besthr_data_view(hr)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.