| ci_fill_colors | R Documentation |
Returns the fill colors used for confidence interval regions in bootstrap distribution plots.
ci_fill_colors(style = "default")
style |
Character string: "default" for original colors, "modern" for updated colors |
A named character vector of hex colors for low, middle, high regions
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.