| compute_significance | R Documentation |
Determines statistical significance by checking if the bootstrap confidence interval for each treatment group overlaps with the control group's mean rank.
compute_significance(hrest)
hrest |
An hrest object from |
A data frame with columns: group, significant (logical), p_value, stars
d <- make_data()
hr <- estimate(d, score, group, nits = 500)
compute_significance(hr)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.