Compute significance from bootstrap distributions
compute_significance.RdDetermines statistical significance by checking if the bootstrap confidence interval for each treatment group overlaps with the control group's mean rank.
Arguments
- hrest
An hrest object from
estimate