Learn R Programming

besthr (version 0.3.2)

group_ns: Get number of observations in a group in a data frame

Description

group_ns groups the provided dataframe by a column and returns a summary dataframe with an column n containg the number of observations in a group

Usage

group_ns(df, quo_group_col)

Arguments

df

input data frame

quo_group_col

quoted group name containing the column to group on