layer_ranked_dots: Create ranked dots layer

View source: R/plot-layers.R

layer_ranked_dotsR Documentation

Create ranked dots layer

Description

Creates a ggplot2 layer showing ranked observations as points, where point size indicates the count of observations at each rank/group combination.

Usage

layer_ranked_dots(data_view, config)

Arguments

data_view

A besthr_data_view object

config

A besthr_plot_config object

Value

A list of ggplot2 layers

Examples


d <- make_data()
hr <- estimate(d, score, group)
dv <- besthr_data_view(hr)
cfg <- besthr_plot_config()
# layer_ranked_dots returns layers to add to a ggplot



besthr documentation built on March 18, 2026, 5:08 p.m.