| layer_ranked_dots | R Documentation |
Creates a ggplot2 layer showing ranked observations as points, where point size indicates the count of observations at each rank/group combination.
layer_ranked_dots(data_view, config)
data_view |
A besthr_data_view object |
config |
A besthr_plot_config object |
A list of ggplot2 layers
d <- make_data()
hr <- estimate(d, score, group)
dv <- besthr_data_view(hr)
cfg <- besthr_plot_config()
# layer_ranked_dots returns layers to add to a ggplot
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.