make_data2: return a sample data set of random values for two groups with...

View source: R/functions.R

make_data2R Documentation

return a sample data set of random values for two groups with three technical reps per group

Description

return a sample data set of random values for two groups with three technical reps per group

Usage

make_data2()

Value

tibble of random values for two groups with three technical reps per group

Examples


 d2 <- make_data2()


besthr documentation built on March 18, 2026, 5:08 p.m.