return a sample data set of random values for two groups with three technical reps per group
make_data2.Rdreturn a sample data set of random values for two groups with three technical reps per group
make_data2.Rdreturn a sample data set of random values for two groups with three technical reps per group