plot_bootstrap_raincloud: Raincloud plot showing bootstrap distributions

View source: R/plot-raincloud.R

plot_bootstrap_raincloudR Documentation

Raincloud plot showing bootstrap distributions

Description

Creates a raincloud plot specifically for bootstrap distributions, showing the distribution of bootstrap mean ranks with jittered points and summary statistics.

Usage

plot_bootstrap_raincloud(
  hrest,
  theme = "modern",
  colors = "okabe_ito",
  config = NULL
)

Arguments

hrest

An hrest object from estimate

theme

the visual theme to use. Either "modern" (default) or "classic"

colors

the color palette to use. Either "okabe_ito" (default), "default", or "viridis"

config

an optional besthr_plot_config object

Value

A ggplot object

Examples


d <- make_data()
hr <- estimate(d, score, group, nits = 100)
plot_bootstrap_raincloud(hr)



besthr documentation built on March 18, 2026, 5:08 p.m.