View source: R/plot-raincloud.R
| plot_bootstrap_raincloud | R Documentation |
Creates a raincloud plot specifically for bootstrap distributions, showing the distribution of bootstrap mean ranks with jittered points and summary statistics.
plot_bootstrap_raincloud(
hrest,
theme = "modern",
colors = "okabe_ito",
config = NULL
)
hrest |
An hrest object from |
theme |
the visual theme to use. Either "modern" (default) or "classic" |
colors |
the color palette to use. Either "okabe_ito" (default), "default", or "viridis" |
config |
an optional besthr_plot_config object |
A ggplot object
d <- make_data()
hr <- estimate(d, score, group, nits = 100)
plot_bootstrap_raincloud(hr)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.